Module: MetofficeDatapoint::Api::MapOverlayMethods
- Included in:
- Client
- Defined in:
- lib/metoffice_datapoint/api/map_overlay_methods.rb
Overview
Public: Wrapper class around the Met Office DataPoint API endpoints
Instance Method Summary collapse
-
#forecast_layer ⇒ Object
Public: Returns when the forecast layers were issued, time steps available, and the URIs of the layers in PNG format.
-
#observation_layer ⇒ Object
Public: Returns when the observation layers were issued, time steps available, and the URIs of the layers in PNG format.
Instance Method Details
#forecast_layer ⇒ Object
Public: Returns when the forecast layers were issued, time steps available, and the URIs of the layers in PNG format. API updates hourly.
Returns a Hash.
12 13 14 |
# File 'lib/metoffice_datapoint/api/map_overlay_methods.rb', line 12 def forecast_layer query('layer/wxfcs/all/json/capabilities') end |
#observation_layer ⇒ Object
Public: Returns when the observation layers were issued, time steps available, and the URIs of the layers in PNG format. API updates every 15 minutes.
Returns a Hash.
20 21 22 |
# File 'lib/metoffice_datapoint/api/map_overlay_methods.rb', line 20 def observation_layer query('layer/wxobs/all/json/capabilities') end |