Module: MetofficeDatapoint::Api::StandaloneMapsMethods
- Included in:
- Client
- Defined in:
- lib/metoffice_datapoint/api/standalone_maps_methods.rb
Overview
Public: Wrapper class around the Met Office DataPoint API endpoints
Instance Method Summary collapse
-
#surface_pressure_map ⇒ Object
Public: Returns when the current surface pressure charts were issued, the time steps available, and the URIs of the surface pressure synoptic analysis and forecast charts in GIF format.
Instance Method Details
#surface_pressure_map ⇒ Object
Public: Returns when the current surface pressure charts were issued, the time steps available, and the URIs of the surface pressure synoptic analysis and forecast charts in GIF format. API is updated twice daily.
Returns a Hash.
12 13 14 |
# File 'lib/metoffice_datapoint/api/standalone_maps_methods.rb', line 12 def surface_pressure_map query('image/wxfcs/surfacepressure/json/capabilities') end |